<?php
/**
 * @package Catch Themes
 * @subpackage Catch Everest
 * @since Catch Everest 2.5
 */


if( ! function_exists( 'catcheverest_is_feed_url_present' ) ) :
	/**
	* Return true if feed url is present
	*
	* @since Catch Everest 2.5
	*/
	function catcheverest_is_feed_url_present( $control ) {
		global $catcheverest_options_settings;

    	$options = $catcheverest_options_settings;

		return ( isset( $options['feed_url'] ) && '' != $options['feed_url'] );
	}
endif;


if( ! function_exists( 'catcheverest_is_header_code_present' ) ) :
	/**
	* Return true if header code is present
	*
	* @since Catch Everest 2.5
	*/
	function catcheverest_is_header_code_present( $control ) {
		global $catcheverest_options_settings;

    	$options = $catcheverest_options_settings;

		return ( isset( $options['analytic_header'] ) && '' != $options['analytic_header'] );
	}
endif;


if( ! function_exists( 'catcheverest_is_footer_code_present' ) ) :
	/**
	* Return true if footer code is present
	*
	* @since Catch Everest 2.5
	*/
	function catcheverest_is_footer_code_present( $control ) {
		global $catcheverest_options_settings;

    	$options = $catcheverest_options_settings;

		return ( isset( $options['analytic_footer'] ) && '' != $options['analytic_footer'] );
	}
endif;

if( ! function_exists( 'catcheverest_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) );
	}
endif;


if( ! function_exists( 'catcheverest_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_demo_slider_inactive( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catcheverest_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && !( 'demo-slider' == $type ) );
	}
endif;


if( ! function_exists( 'catcheverest_is_post_slider_active' ) ) :
	/**
	* Return true if post slider is active
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catcheverest_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'post-slider' == $type );
	}
endif;

if( ! function_exists( 'catcheverest_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catcheverest_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'page-slider' == $type );
	}
endif;

if( ! function_exists( 'catcheverest_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catcheverest_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'image-slider' == $type );
	}
endif;


if( ! function_exists( 'catcheverest_is_category_slider_active' ) ) :
	/**
	* Return true if category slider is active
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'catcheverest_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( 'enable-slider-allpage' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'enable-slider-homepage' == $enable ) ) && 'category-slider' == $type );
	}
endif;

if( ! function_exists( 'catcheverest_is_header_featured_image_enabled' ) ) :
	/**
	* Return true if header featured image enabled
	*
	* @since Catch Everest Pro 3.4
	*/
	function catcheverest_is_header_featured_image_enabled( $control ) {

		$enable = $control->manager->get_setting( 'catcheverest_options[enable_featured_header_image]' )->value();

		return ( 'disable' != $enable );

	}
endif;
